Peer Instruction: Using Objects Multiple Choice Questions
---------------------------------------------------------

.. mchoice:: bs-objects-2-19
   :author: Beth Simon
   :practice: T
   :answer_a: Type, method/message name, parameter list
   :answer_b: Class, method/message name, parameter list
   :answer_c: Object, method/message name, parameter list
   :correct: c
   :feedback_a: Incorrect. A type can refer to an integer, string, array, or similar data type, but that is not what is being referenced in this answer
   :feedback_b: Incorrect. Turtle is the class in this example, but we are not calling the class itself in line 2.
   :feedback_c: Correct. turtle1 is created using the Turtle() constructor, and is an object of the Turtle class

   What are the components of the second line of code?

   .. code-block:: java

      Turtle turtel1 = new Turtle();
      turtle1.turn(-45);

